==> taffybar-4.0.3-211-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-K0FwwnbvWNELfQBQHhONyK
key:                    taffybar-4.0.3-K0FwwnbvWNELfQBQHhONyK
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    9eae66546c254b0d58267d6fda8eef66
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-K0FwwnbvWNELfQBQHhONyK
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype dl
    bz2 png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0
    ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-BFFxaGYzyClKeVHNV9iJMs
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-7gDrgQT36z4IN6MqKXM4jU containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    dbus-1.3.3-FUuzk73YCYaLEFEutEZ918
    dbus-hslogger-0.1.0.1-BfXhcOhSMs71WUAIv1BFOP directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.3-BsEEiS8qvcZFl2xdEdw9HV
    enclosed-exceptions-1.0.3-2wx4gK3aafwC48ZsCOyxHS filepath-1.4.2.2
    gi-cairo-connector-0.1.1-3J4bkMyBUCz9tAfXSEKAH8
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    gi-gdk-3.0.28-50K3I0O5Y879oZWxHBvSDx
    gi-gdkpixbuf-2.0.32-GRSsmFaVB03mVmXlm9A3G
    gi-gdkx11-3.0.13-9lwtljDxuJK1FrdvxfXw8t
    gi-glib-2.0.30-FFXXLakPWPe3MXrE96VoRn
    gi-gtk-3.0.41-FOoil3GxzSoa51mHCR5l2
    gi-gtk-hs-0.3.17-GtbNUCBytuN8N5KhikHaNq
    gi-pango-1.0.29-KGgZxDlCGNaJtKbrqpYnIv
    gtk-sni-tray-0.1.8.1-4J4oIb5cKc0HDOnjcXqMsX
    gtk-strut-0.1.3.2-L8fxPPDbJGqESdQOtvhS6i
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-LbQHdu1407K3Abhs0Xw2Vi
    http-client-0.7.19-FAI99Ioi5R36WLiLxr7VX7
    http-client-tls-0.3.6.4-GiVBNNbKgJLCx3fO8pPpRI
    http-conduit-2.3.9.1-6m79Y0ZNJvKK9qOtarTSOn
    http-types-0.12.4-Lh5dVrkMNHmKdCH2kircer
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-5ePY1yCKz45qNPHFPlOcS
    scotty-0.22-90veyUP8URc7FJ2mxAwUTa
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    status-notifier-item-0.3.1.0-BUaRGeobdNrDEDNQZhjIbD stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-7NBKOoZhGiHIFQMCIy3P8 unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-20ThuBvAHy7IV4eTdjpOMB
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-7hxyFM6N3li3AUTZFzLueX

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> taffybar-4.0.3-212-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-D5IYxmd6rasIb5eeyEcUhn
key:                    taffybar-4.0.3-D5IYxmd6rasIb5eeyEcUhn
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    639d7515db657b1e9df1b9d3f09ab340
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-D5IYxmd6rasIb5eeyEcUhn
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype dl
    bz2 png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0
    ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-3hHR5KklJGl1CI948WcOXa
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    aeson-2.1.2.1-CM1TyKExMgH6p2KQqrdDHD
    ansi-terminal-1.0.2-7enoCfAnx2SGJDVGgMW6rt base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-P2VVzWMvOMICi7Nj7BTmx containers-0.6.7
    data-default-0.7.1.2-434WfftxN7fJEVVCTZ9w4g
    dbus-1.3.3-Ehb3rEJNpUO519xRNi99W6
    dbus-hslogger-0.1.0.1-LjgJxaDIwwqHotPg4tPsvm directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD either-5.0.3-5I6ATpayUCHZDT7SQ31C
    enclosed-exceptions-1.0.3-J3W4To7YO1PJBYGPesDQ4k filepath-1.4.2.2
    gi-cairo-connector-0.1.1-5qCJ4dGnOpP5RgvflGl6XC
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    gi-gdk-3.0.28-DwxgZIpqJP2KvEEWoDBEhp
    gi-gdkpixbuf-2.0.32-JL7rtD5rYmQGSyAQf4iq6c
    gi-gdkx11-3.0.13-LMRN5GPW6nGODZcSFGfFC
    gi-glib-2.0.30-7nrxEmus48vLJuso9OM1ak
    gi-gtk-3.0.41-HljlSQCxAi59z7S5HC1QtZ
    gi-gtk-hs-0.3.17-GArGNnHr6Q88eqot6a9eOj
    gi-pango-1.0.29-8Y4V0i0bBhkE0jXtKo8T0x
    gtk-sni-tray-0.1.8.1-AGXSqXECIR6JejBxaxXH0c
    gtk-strut-0.1.3.2-3WRMBST35p91ss5lkkThRF
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-67tEjeRqZPsKjQKIEdwOpU
    http-client-0.7.19-9qUcwTVQqbvEShQpYcde6b
    http-client-tls-0.3.6.4-KN3JTiWE2EI1kyisYRtf57
    http-conduit-2.3.9.1-9RvHGJGxwHHJpUO7Zqiogv
    http-types-0.12.4-9tb655S6p8NAIcFLCK3aeD
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-2QfDol6D5mJHd9hpTIyjO0
    scotty-0.22-Bm3XRC4aQLU95TsGE4ECY7
    split-0.2.5-eIzaXXEViC764D7Uvb52H
    status-notifier-item-0.3.1.0-7qf0EG9NHFRJNag2TR5sV4 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-7NBKOoZhGiHIFQMCIy3P8 unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-3eUT8qU6YctGGjdPSPwDcy
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-HpH47KT57td7lumBCGr9mt

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
